<!--
 * @Author: hzy
 * @Date: 2021-11-04 11:00:00
 * @LastEditors: hyz
 * @LastEditTime: 2020-04-23 17:00:22
 * @Description: 用机时长页面
 -->
<template>
  <div>
    <!-- 总电量显示 -->
    <!-- <div class="total-electric">
      <span>当前累计总用机时长：{{ daytotle }} h</span>
    </div> -->
    <!-- 按钮组 -->
    <div class="use-time-button-group">
      <div class="use-time-btn-mask">
        <div
          v-for="(item, index) in typeList"
          :key="index"
          class="use-time-btn"
          @click="btnIndex(index)"
          :style="{
            color: '#162c54',
            background: index !== selcetedIndex ? '#dde0e1' : 'white'
          }"
        >
          {{ item }}
        </div>
      </div>
    </div>
    <!-- 图表区 -->
    <div class="chart-bg">
      <div v-show="!isNoData">
        <span class="total">{{ textList[selcetedIndex] + this[totalType[selcetedIndex]] + 'h' }}</span>
      </div>
      <gree-block class="chart-block" v-show="!isNoData">
        <div class="chart-canves" ref="day" v-show="selcetedIndex === 0" />
        <!-- <div class="chart-canves" ref="week" v-show="selcetedIndex === 1" /> -->
        <div class="chart-canves" ref="month" v-show="selcetedIndex === 1" />
        <div class="chart-canves" ref="year" v-show="selcetedIndex === 2" />
        <div class="chart-canves" ref="overTheYear" v-show="selcetedIndex === 3" />
        <span v-show="!isNoData" class="unit-txt">{{ unitType[selcetedIndex] }}</span>
      </gree-block>
      <div v-show="isNoData" class="isNoData">
        <p class="no-data-text" v-text="'当前无用机信息'" />
      </div>
      <!-- <gree-row v-show="!isNoData" class="tip">该设备的用电量仅供参考</gree-row> -->
    </div>
  </div>
</template>

<script>
import echarts from 'echarts';
import { Header, Row, Col, Block, Divider, Dialog } from 'gree-ui';
import { mapState, mapMutations } from 'vuex';
import chartsConfig from '@/mixins/echarts';
import { showToast, clearHistoricalPhotovoltaicPowerData, pluginHttp } from '@PluginInterface';

export default {
  name: 'UseTimerChart',
  components: {
    [Header.name]: Header,
    [Row.name]: Row,
    [Col.name]: Col,
    [Block.name]: Block,
    [Divider.name]: Divider,
    [Dialog.name]: Dialog
  },
  mixins: [chartsConfig],
  data() {
    const nowDate = new Date();
    const year = nowDate.getFullYear();
    return {
      currentYear: year,
      DEBUG: false, // 测试
      typeList: ['日报', '月报', '年报', '历年'],
      textList: ['今日累计用机时长: ', '本月累计用机时长: ', '今年累计用机时长: ', '累计总用机时长: '],
      totalType: ['dayTotal', 'monthTotal', 'yearTotal', 'allTotal'],
      unitType: [' ', '/日', '/月', '/年'],
      selcetedIndex: 0,
      useTimeyearChart: '',
      useTimemonthChart: '',
      useTimedayChart: '',
      useTimeweekChart: '',
      overTheYearsChart: '',
      isNoData: true, // 无数据显示
      dayTotal: 0, // 日累计用电量
      // monthTotal: 0,
      // yearTotal: 0,
      // allTotal: 0,
      tooltip: {},
      overTheYearsTooltip: {},
      otherTooltip: {}
    };
  },
  computed: {
    ...mapState('control', {
      mac: state => state.mac,
      isClear: state => state.isClear,
      chartData: state => state.chartData,
      monthTotal: state => state.chartData.monthTotal || 0,
      yearTotal: state => state.chartData.yearTotal || 0,
      allTotal: state => state.chartData.allTotal || 0
    }),
    yearList() {
      return Array.from({ length: 4 }, (v, i) => {
        const value = this.currentYear - i;
        return value;
      }).reverse();
    }
  },
  mounted() {
    // this.getWeekData();
    this.initCharts(); // 初始化图表
    // try {
    //   hideLoading();
    // } catch (e) {
    //   e;
    // }
  },
  beforeDestroy() {
    this.setChartData({ useTimeDayChart: null });
  },
  methods: {
    ...mapMutations('control', {
      setChartData: 'SET_CHART_DATA'
    }),
    // 初始化图表
    async initCharts() {
      this.useTimedayChart = echarts.init(this.$refs.day);
      this.useTimemonthChart = echarts.init(this.$refs.month);
      this.useTimeyearChart = echarts.init(this.$refs.year);
      this.overTheYearsChart = echarts.init(this.$refs.overTheYear);
      await this.getDayData();
      await this.getYearData();
    },
    // 当前选择类型请求对应的数据
    btnIndex(index) {
      this.DEBUG ? this.setChartData(this.useTimerDebugData) : ''; // 测试数据
      this.selcetedIndex = index;
      this.tooltip = {
        position: function positionSetting(point, params, dom, rect, size) {
          //其中point为当前鼠标的位置，size中有两个属性：viewSize和contentSize，分别为外层
          var x = point[0]; //
          var boxWidth = size.contentSize[0];
          return [x - boxWidth / 2 + 5, '12%'];
        },
        formatter: '当年用电量：{c} kW·h',
        trigger: 'axis', // 数据项图形触发
        axisPointer: {
          lineStyle: {
            type: 'dashed'
          }
        },
        backgroundColor: '#77a7e0',
        // padding: 3,
        show: true,
        textStyle: {
          fontFamily: 'FZLTH--GB1-4',
          fontSize: '36px',
          color: '#fff'
        }
      };
      this.otherTooltip = {
        position: function positionSetting(point, params, dom, rect, size) {
          //其中point为当前鼠标的位置，size中有两个属性：viewSize和contentSize，分别为外层
          var x = point[0]; //
          var boxWidth = size.contentSize[0];
          return [x - boxWidth / 2 + 5, '12%'];
        },
        // formatter: '该日用机时长：{c}  h',
        trigger: 'axis', // 数据项图形触发
        axisPointer: {
          lineStyle: {
            type: 'dashed'
          }
        },
        backgroundColor: '#77a7e0',
        // padding: 3,
        show: true,
        textStyle: {
          fontFamily: 'FZLTH--GB1-4',
          fontSize: '36px',
          color: '#fff'
        }
      };
      this.overTheYearsTooltip = {
        position: function positionSetting(point, params, dom, rect, size) {
          //其中point为当前鼠标的位置，size中有两个属性：viewSize和contentSize，分别为外层
          var x = point[0]; //
          var boxWidth = size.contentSize[0];
          return [x - boxWidth / 2 + 5, '12%'];
        },
        // formatter: '当年用电量：{c} h',
        trigger: 'axis', // 数据项图形触发
        axisPointer: {
          lineStyle: {
            type: 'dashed'
          }
        },
        backgroundColor: '#77a7e0',
        // padding: 3,
        show: true,
        textStyle: {
          fontFamily: 'FZLTH--GB1-4',
          fontSize: '36px',
          color: '#fff'
        }
      };
      const dataZoom = [
        {
          show: false,
          start: 0,
          endValue: 12
        },
        {
          type: 'inside'
        }
      ];
      const dayDataZoom = [
        {
          show: false,
          start: 0,
          endValue: 6
        },
        {
          type: 'inside'
        }
      ];
      switch (index) {
        case 0:
          this.chartData.useTimedayChart ? this.dayChartSet(dayDataZoom) : this.getDayData();
          break;
        case 1:
          this.chartData.useTimemonthChart ? this.monthChartSet(dataZoom) : this.getMonthData();
          break;
        case 2:
          this.chartData.useTimeyearChart ? this.yearChartSet(dataZoom) : this.getYearData();
          break;
        case 3:
          this.chartData.overTheYearsChart ? this.overTheYearsChartSet(dataZoom) : this.getOverTheYearData();
          break;
        // case 4:
        //   this.chartData.overTheYearsChart ? this.overTheYearsChartSet(dataZoom) : this.getOverTheYearData();
        //   break;
        default:
          this.chartData.useTimeweekChart ? this.dayChartSet() : this.getDayData();
          break;
      }
    },
    // 清除电量dialog
    cleanElc() {
      Dialog.confirm({
        title: '提示',
        content: '电量清零后不可恢复，是否确定清零？',
        confirmText: '确定',
        onConfirm: () => this.cleanElcInterface(),
        cancelText: '取消',
        onCancel: () => console.log('[Dialog.confirm] cancel clicked')
      });
    },
    async getDayData() {
      await pluginHttp('/gateway/portrait-recommend/portrait/statistical/dailyReport', '', JSON.stringify({ mac: this.mac }), 'POST', 'iot7', '')
        .then(_res => {
          const dailyReport = JSON.parse(_res).data;
          const dailyData = dailyReport.data;
          console.log('日报--------------------', dailyData);
          //  日求和
          this.dayTotal = 0;
          let result = 0;
          Object.values(dailyData).forEach(item => {
            result = Number(item) + result;
            return result;
          });
          this.dayTotal = result.toFixed(2);

          const day = [];
          const count = [];
          for (let i = 0; i < 12; i += 1) {
            day[i] = 0;
            count[i] = 2 * (i + 1) + ':00';
          }
          this.isNoData = !dailyReport;
          this.setChartData({ useTimedayChart: [dailyData, count] });
          this.refreshChart(dailyData, count, 'useTimedayChart');
        })
        .catch(err => console.error(err));
    },
    getMonthData() {
      pluginHttp('/gateway/portrait-recommend/portrait/statistical/monthReport', '', JSON.stringify({ mac: this.mac }), 'POST', 'iot7', '')
        .then(_res => {
          const monthReport = JSON.parse(_res).data;
          const monthData = monthReport.data;
          console.log('monthData', monthData);
          console.log('xxxx-----------monthData', monthData);
          //  月求和
          // this.monthTotal = 0;
          let result = 0;
          Object.values(monthData).forEach(item => {
            result = Number(item) + result;
            return result;
          });
          // this.monthTotal = result.toFixed(2);
          const count = [];
          for (let i = 0; i < 31; i += 1) {
            count[i] = i + 1;
          }
          this.isNoData = !monthReport;
          console.log('xxxxxx----------count', count);
          this.setChartData({ useTimemonthChart: [monthData, count], monthTotal: result.toFixed(2) });
          this.refreshChart(monthData, count, 'useTimemonthChart');
        })
        .catch(err => console.error(err));
    },
    getYearData() {
      pluginHttp('/gateway/portrait-recommend/portrait/statistical/yearReport', '', JSON.stringify({ mac: this.mac }), 'POST', 'iot7', '')
        .then(_res => {
          const yearReport = JSON.parse(_res).data;
          const yearData = yearReport.data;
          //  年求和
          // this.yearTotal = 0;
          let result = 0;
          Object.values(yearData).forEach(item => {
            result = Number(item) + result;
            return result;
          });
          // this.yearTotal = result.toFixed(2);
          const count = [];
          for (let i = 0; i < 12; i += 1) {
            // week[i] = 0;
            count[i] = i + 1;
          }
          this.isNoData = !yearReport;
          this.setChartData({ useTimeyearChart: [yearData, count], yearTotal: result.toFixed(2) });
          this.refreshChart(yearData, count, 'useTimeyearChart');
        })
        .catch(err => console.error(err));
    },
    getOverTheYearData() {
      pluginHttp('/gateway/portrait-recommend/portrait/statistical/overTheYearsReport', '', JSON.stringify({ mac: this.mac }), 'POST', 'iot7', '').then(
        _res => {
          const yearReport = JSON.parse(_res).data;
          const yearData = yearReport.data;
          const count = this.yearList;
          let result = 0;
          Object.values(yearData).forEach(item => {
            result = Number(item) + result;
            return result;
          });
          // this.allTotal = result.toFixed(2);
          this.isNoData = !yearReport;
          this.setChartData({ overTheYearsChart: [yearData, count], totalDays: Math.round(result), allTotal: result.toFixed(2) });
          this.refreshChart(yearData, count, 'overTheYearsChart');
        }
      );
    },
    // 清除电量接口
    cleanElcInterface() {
      // showLoading();
      clearHistoricalPhotovoltaicPowerData(this.mac)
        .then(result => {
          const res = JSON.parse(result);
          // 判断是否成功清除电量
          if (res.r === 400) {
            console.log('Api调用失败');
          } else if (res.r === 200) {
            console.log('成功请求，清除电量');
            this.sendCtrl({ Electnumzero: 0 });
          } else if (res.r === 10700) {
            showToast('您没有权限清除电量哦', 0);
          } else {
            console.log('失败！其他原因');
          }
        })
        .catch(err => {
          console.log('err', err);
        });
    },
    refreshChart(value, count, type) {
      this.otherOpt.xAxis.data = count;
      this.otherOpt.series[0].data = value;
      this.dayChartOpt.xAxis.data = count;
      this.dayChartOpt.series[0].data = value;
      this[type].setOption(type === 'useTimedayChart' ? this.dayChartOpt : this.otherOpt, true);
      this.$nextTick(() => {
        this[type].resize();
      });
    },
    dayChartSet(dayDataZoom) {
      this.tooltip.formatter = '该时段用机时长:{c} h';
      this.dayChartOpt.tooltip = this.tooltip;
      this.dayChartOpt.dataZoom = dayDataZoom;
      this.dayChartOpt.grid = { left: '0%', top: '25%', right: '2%', bottom: '10%', containLabel: false };
      this.refreshChart(this.chartData.useTimedayChart[0], this.chartData.useTimedayChart[1], 'useTimedayChart');
    },
    weekChartSet(dataZoom) {
      this.otherOpt.tooltip = this.otherTooltip;
      this.otherOpt.tooltip.formatter = '该日用机时长：{c} h';
      this.otherOpt.dataZoom = dataZoom;
      this.otherOpt.grid = { left: '0%', top: '25%', right: '2.5%', bottom: '10%' };
      this.refreshChart(this.chartData.useTimeweekChart[0], this.chartData.useTimeweekChart[1], 'useTimeweekChart');
    },
    monthChartSet(dataZoom) {
      this.otherOpt.tooltip = this.otherTooltip;
      this.otherOpt.tooltip.formatter = '该日用机时长：{c} h';
      this.otherOpt.dataZoom = dataZoom;
      this.otherOpt.grid = { left: '0%', top: '25%', right: '2%', bottom: '10%' };
      this.refreshChart(this.chartData.useTimemonthChart[0], this.chartData.useTimemonthChart[1], 'useTimemonthChart');
    },
    yearChartSet(dataZoom) {
      this.otherOpt.tooltip = this.otherTooltip;
      this.otherOpt.tooltip.formatter = '该月用机时长：{c} h';
      this.otherOpt.dataZoom = dataZoom;
      this.otherOpt.grid = { left: '0%', top: '25%', right: '2%', bottom: '10%' };
      this.refreshChart(this.chartData.useTimeyearChart[0], this.chartData.useTimeyearChart[1], 'useTimeyearChart');
    },
    overTheYearsChartSet() {
      this.otherOpt.tooltip = this.overTheYearsTooltip;
      this.otherOpt.tooltip.formatter = '该年用机时长：{c} h';
      // this.otherOpt.dataZoom = [];
      this.otherOpt.grid = { left: '0%', top: '25%', right: '2%', bottom: '10%' };
      this.refreshChart(this.chartData.overTheYearsChart[0], this.chartData.overTheYearsChart[1], 'overTheYearsChart');
    },
    goBack() {
      this.$router.go(-1);
    }
  }
};
</script>
